@@ -14,17 +14,21 @@ type Gui struct {
 }
 
 // New builds a new gui handler.
-func New(g *gocui.Gui, c *client.Client) *Gui {
-	return &Gui{
+func New(g *gocui.Gui, c *client.Client) (*Gui, error) {
+
+	gui := Gui{
 		g: g,
 		c: c,
 	}
+
+	if err := gui.prepare(); err != nil {
+		return &gui, err
+	}
+
+	return &gui, nil
 }
 
-// Run setup the gui with keybindings and start the mainloop.
-func (gui *Gui) Run() error {
-	defer gui.g.Close()
-
+func (gui *Gui) prepare() error {
 	gui.g.Highlight = true
 	gui.g.Cursor = true
 	gui.g.Mouse = true
@@ -36,9 +40,19 @@ func (gui *Gui) Run() error {
 		return err
 	}
 
+	return nil
+}
+
+// Run setup the gui with keybindings and start the mainloop.
+func (gui *Gui) Run() error {
 	if err := gui.g.MainLoop(); err != nil && !errors.Is(err, gocui.ErrQuit) {
 		return err
 	}
 
 	return nil
 }
+
+// Gui returns a pointer of a gocui.Gui instance.
+func (gui *Gui) Gui() *gocui.Gui {
+	return gui.g
+}
